==> uncrustify_0.72.0+dfsg1.orig.tar.xz: uncrustify-0.72.0+dfsg1/src/align_typedefs.cpp <==
/**
 * @file align_typedefs.cpp
 *
 * @author  Guy Maurel
 * split from align.cpp
 * @author  Ben Gardner
 * @license GPL v2+
 */

#include "align_typedefs.h"

#include "align_stack.h"
#include "chunk_list.h"
#include "log_rules.h"

using namespace uncrustify;


void align_typedefs(size_t span)
{
   LOG_FUNC_ENTRY();

   AlignStack as;

   as.Start(span);
   log_rule_B("align_typedef_gap");
   as.m_gap = options::align_typedef_gap();
   log_rule_B("align_typedef_star_style");
   as.m_star_style = static_cast<AlignStack::StarStyle>(options::align_typedef_star_style());
   log_rule_B("align_typedef_amp_style");
   as.m_amp_style = static_cast<AlignStack::StarStyle>(options::align_typedef_amp_style());

   chunk_t *c_typedef = nullptr;
   chunk_t *pc        = chunk_get_head();

   while (pc != nullptr)
   {
      if (chunk_is_newline(pc))
      {
         as.NewLines(pc->nl_count);
         c_typedef = nullptr;
      }
      else if (c_typedef != nullptr)
      {
         if (pc->flags.test(PCF_ANCHOR))
         {
            as.Add(pc);
            LOG_FMT(LALTD, "%s(%d): typedef @ %zu:%zu, tag '%s' @ %zu:%zu\n",
                    __func__, __LINE__, c_typedef->orig_line, c_typedef->orig_col,
                    pc->text(), pc->orig_line, pc->orig_col);
            c_typedef = nullptr;
         }
      }
      else
      {
         if (chunk_is_token(pc, CT_TYPEDEF))
         {
            c_typedef = pc;
         }
      }
      pc = chunk_get_next(pc);
   }
   as.End();
} // align_typedefs

==> uncrustify_0.78.1+dfsg1.orig.tar.xz: uncrustify-0.78.1+dfsg1/src/align_typedefs.cpp <==
/**
 * @file align_typedefs.cpp
 *
 * @author  Guy Maurel
 * split from align.cpp
 * @author  Ben Gardner
 * @license GPL v2+
 */

#include "align_typedefs.h"

#include "align_stack.h"
#include "log_rules.h"

constexpr static auto LCURRENT = LALTD;

using namespace uncrustify;


void align_typedefs(size_t span)
{
   LOG_FUNC_ENTRY();

   AlignStack as;

   as.Start(span);
   log_rule_B("align_typedef_gap");
   as.m_gap = options::align_typedef_gap();
   log_rule_B("align_typedef_star_style");
   as.m_star_style = static_cast<AlignStack::StarStyle>(options::align_typedef_star_style());
   log_rule_B("align_typedef_amp_style");
   as.m_amp_style = static_cast<AlignStack::StarStyle>(options::align_typedef_amp_style());

   Chunk *c_typedef = Chunk::NullChunkPtr;
   Chunk *pc        = Chunk::GetHead();

   while (pc->IsNotNullChunk())
   {
      if (pc->IsNewline())
      {
         as.NewLines(pc->GetNlCount());
         c_typedef = Chunk::NullChunkPtr;
      }
      else if (c_typedef->IsNotNullChunk())
      {
         if (pc->TestFlags(PCF_ANCHOR))
         {
            as.Add(pc);
            LOG_FMT(LALTD, "%s(%d): typedef @ %zu:%zu, tag '%s' @ %zu:%zu\n",
                    __func__, __LINE__, c_typedef->GetOrigLine(), c_typedef->GetOrigCol(),
                    pc->Text(), pc->GetOrigLine(), pc->GetOrigCol());
            c_typedef = Chunk::NullChunkPtr;
         }
      }
      else
      {
         if (pc->Is(CT_TYPEDEF))
         {
            c_typedef = pc;
         }
      }
      pc = pc->GetNext();
   }
   as.End();
} // align_typedefs
